rmtoo - Requirements Management Tool
Author: flonatel GmbH & Co. KG
Keywords: rmtoo requirement requirements management tool utility open source python
Date: 2010-04-26T08:49:37+02:00

| # rmtoo - Requirements Management Tool
Overview Project Download State Documentation Links Statistics License | ## Overview rmtoo is a free and open source requirements management tool. rmtoo uses a different approach than most other requirements management tools: it comes as a command line tool which is optimized for handling requirements. The power of rmtoo is that a typical development environment can handle the input and output files. Example: if there is a need for handling baselines (and mostly there is), use a revision control system of your choice (git, mercurial, subversion, ...). They can handle different revisions, baselining, tagging, branching and many different things perfectly well. Let one thing do one thing. ### rmtoo is not rmtoo is not a fully integrated do-everything requirements management tool with a sophisticated GUI, different database backends. Such tools can be found in the links section. ## Project The project is hosted on sourceforge. There exists the project infrastructure as git repository, bug-tracker, news and forums. ## State The current state of the project is beta. rmtoo works well as a requirements management tool and is used in commercial projects. But currently it lacks some major features which are planned but not implemented yet. Because of the lack of some major features it might currently not usable for some use-cases. Some missing features are: Missing traceability when a requirement changes No test-case integration available Integration in Makefiles missing ## Documentation rmtoo comes with man pages which describe the functionality, input- and output files (man pages are currently not finished). Also rmtoo comes with a set of requirements that describe the rmtoo functionality itself. This is a good point to get an impression about rmtoo and a good starting point to work with rmtoo. ### Presentation: Introduction to rmtoo There is a presentation available which describes the design, features and basics. ### Requirements of rmtoo A document is available which describes the requirements for rmtoo itself. Also, because the document was created with the help of rmtoo this can be seen as an example output document, including backlog, list of requirements that must be further elaborated and all requirements. ### Requirements Dependency Graph The requirements dependency graph is one output of the rmtoo. There is a requirements dependency graph that describes the current state of the rmtoo itself. Also this can be seen as an example output of rmtoo itself. ## Links There is a long list of requirement management tools. Mostly all of them are fully integrated software products. This following lists some WEB-sites where lists of available requirements management tools can be found. Requirements Management Tools:List of available requirement management tools. This WEB-site also discusses a lot of different aspects of requirement management INCOSE Requirements Management Tools Survey: The International Council on Systems Engineering provides a list of requirements management tools OSRMT: This is an open source requirements management tool. This comes with GUI and is fully integrated. ## Statistics ### Statistics from ohloh
### Statistics from SourceForge SourceForge provides a download statistics for the project. ## License The source is released under GPLv3. ### Legal flonatel GmbH & Co. KG takes over no liability for websites that are referred to via hyperlink. We dissociate ourselves from all contents of these linked sites. flonatel has no influence on these pages' content, the content is not our own.